\name{NewCtbn}
\alias{NewCtbn}

\title{
NewCtbn
}

\description{
Creation of a new continuous-time Bayesian network (CTBN) object calling the respective C++ function.
}

\usage{
NewCtbn (vars, bn.str=NULL, bn.cpts=NULL, dyn.str=NULL, dyn.cims=NULL)
}

\arguments{

\item{vars}{dataframe n x 2. It is used to define the variables of the CTBN model.
Each row consists of the name (string) of n variables Xn and a value (integer) corresponding of the number of values that the variable can assume (defined from 0 to value-1, -1 if unknown).
}

\item{bn.str}{dataframe k x 2. It is used to define the structure of the initial Bayesian network (specified as a directed acyclic graph). Each row consists of the name of the parent of Xn (from) and the name of Xn (to). Both names must be contained in the \code{vars} dataframe (case sensitive).
}

\item{bn.cpts}{list. List (I) of lists (II) of dataframes (III), in which the I level contains the nodes Xn, the second level contains the parents of Xn (Xn|U), and the III level contains the values of Xn given a particular instantiation of its parents (Xn|u) specified as a dataframe. This dataframe is 1 x m, where m is number of values that Xn can assume (specified in the column header that must be from 0 to value-1), and the row contains the respective probabilities (that must sum up to 1). The names contained in the I level list must be Xn and the names of the II level list must be in the form Xn$U=u.
}

\item{dyn.str}{dataframe k x 2. It is used to define the structure of the dynamic structure (possibly cycle). Each row consists of the name of the parent of Xn (from) and the name of Xn (to). Both names must be contained in the \code{vars} dataframe (case sensitive).
}

\item{dyn.cims}{list. List (I) of lists (II) of dataframes (III), in which the I level contains the nodes Xn, the second level contains the parents of Xn (Xn|U), and the III level contains the values of Xn given a particular instantiation of its parents (Xn|u) specified as a dataframe. This dataframe is m x m, where m is number of values that Xn can assume (specified in the column header that must be from 0 to value-1) and it contains the conditional intensity probabilities (each row must sum up to 0). The names contained in the I level list must be Xn and the names of the II level list must be in the form Xn$U=u.
}
}

\value{
External pointer to the CTBN C++ model.
\code{NULL} in the case of errors.
}

\note{
You own the external pointer, so remember to delete it using the \code{\link{DeleteCtbn}} function only.
}

\seealso{
 \code{\link{DeleteCtbn}}, \code{\link{CloneCtbn}} 
}

\examples{

# files
vars.file     <- system.file("DrugNetwork", "DrugNetwork_Vars.txt",       package="ctbn")
bn.str.file   <- system.file("DrugNetwork", "DrugNetwork_BN_Struct.txt",  package="ctbn")
bn.cpts.file  <- system.file("DrugNetwork", "DrugNetwork_BN_CPTs.txt",    package="ctbn")
dyn.str.file  <- system.file("DrugNetwork", "DrugNetwork_Dyn_Struct.txt", package="ctbn")
dyn.cims.file <- system.file("DrugNetwork", "DrugNetwork_Dyn_CIMs.txt",   package="ctbn")

# variables
vars     <- read.table(    vars.file ,   sep=",", header=TRUE)
# static part
bn.str   <- read.table(    bn.str.file,  sep=",", header=TRUE)
bn.cpts  <- ReadProbStruct(bn.cpts.file)
# dynamic part
dyn.str  <- read.table(    dyn.str.file, sep=",", header=TRUE)
dyn.cims <- ReadProbStruct(dyn.cims.file)

# default constructor
xpCtbn   <- NewCtbn(vars,bn.str=bn.str,bn.cpts=bn.cpts,dyn.str=dyn.str,dyn.cims=dyn.cims)

# delete ctbn
xpCtbn    <- DeleteCtbn(xpCtbn)
garbage   <- gc()
}

\keyword{ create ctbn }
