\name{NewInfEngine}
\alias{NewInfEngine}

\title{
NewInfEngine
}

\description{
Creation of a new inference engine object.
}

\usage{
NewInfEngine (inf.type="exact", hold=FALSE, 
              num.samples=100, burn.iters=100, eps=1e-5)
}

\arguments{

\item{inf.type}{character. Inference type: \code{exact}, \code{importance},  \code{gibbs},  \code{gibbsaux},  \code{meanfield}.}

\item{hold}{logical. If you are using the same model and the same data, you can preserve the past inference computations using \code{hold=TRUE}.}

\item{num.samples}{integer. Number of samples for \code{importance}, \code{gibbs}, \code{gibbsaux} inference engines.}

\item{burn.iters}{integer. Number of burn-in iterations for \code{gibbs}, \code{gibbsaux} inference engines.}

\item{eps}{numeric. Epsilon value for \code{meanfield} inference engine.}
}

\value{
External pointer to the inference engine C++ model.
\code{NULL} in the case of errors.
}

\note{
You own the external pointer, so remember to delete it using the \code{\link{DeleteInfEngine}} function only.
}

\seealso{
 \code{\link{DeleteInfEngine}}, \code{\link{GetInfEngineType}} 
}

\examples{

# load ctbn and trajectory
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
trj.file  <- system.file("DrugNetwork", "Trajectory.csv",    package="ctbn")
trj       <- read.table(trj.file, sep=",", header=TRUE, check.names=FALSE)
xpCtbn    <- LoadRCtbn(ctbn.file)

# advanced option: use an inference engine object for queries
var1 <- "Concentration"
var2 <- "Hungry"
sample.part        <- trj
sample.part[,var1] <- -1
sample.part[,var2] <- -1

engine  <- NewInfEngine(inf.type="importance", num.samples=1000)
print(GetInfEngineType(engine))
QueryCtbnStats(xpCtbn, sample.part, c("Hungry"), inf.engine=engine)
engine  <- DeleteInfEngine(engine)
garbage <- gc()

# if you are using the same model and the same data,
# you can preserve the past inference computations using the hold flag
engine  <- NewInfEngine(inf.type="importance", num.samples=1000, hold=TRUE)
print(GetInfEngineType(engine))
QueryCtbnStats(xpCtbn, sample.part, c("Hungry"), inf.engine=engine)
QueryCtbnStats(xpCtbn, sample.part, c("Concentration"), inf.engine=engine)
print(GetInfEngineType(engine))
engine  <- DeleteInfEngine(engine)
garbage <- gc()

# this reset the past computations (the model has been changed)
xpCtbn2 <- CloneCtbn(xpCtbn)
QueryCtbnStats(xpCtbn2, sample.part, c("Hungry"), inf.engine=engine)
engine  <- DeleteInfEngine(engine)
xpCtbn2 <- DeleteCtbn(xpCtbn2)
garbage <- gc()

# delete ctbn
xpCtbn  <- DeleteCtbn(xpCtbn)
garbage <- gc()
}

\keyword{ create inference engine }
