\name{QueryCtbnStats}
\alias{QueryCtbnStats}

\title{
QueryCtbnStats
}

\description{
Perform the query to the CTBN model about the expected time spent in a state and the expected number of transitions from one state to another state of the given variables.
}

\usage{
QueryCtbnStats (xpCtbn, evid, vars, inf.type="exact", 
                num.samples=100, burn.iters=100, eps=1e-5, inf.engine=NULL)
}

\arguments{

\item{xpCtbn}{external pointer to the CTBN C++ model.}

\item{evid}{dataframe. Evidence specified as a trajectory.}

\item{vars}{vector of characters. This vector contains the n variables names to perform the query.}

\item{inf.type}{character. Inference type: \code{exact}, \code{importance},  \code{gibbs},  \code{gibbsaux},  \code{meanfield}.}

\item{num.samples}{integer. Number of samples for \code{importance}, \code{gibbs}, \code{gibbsaux} inference engines.}

\item{burn.iters}{integer. Number of burn-in iterations for \code{gibbs}, \code{gibbsaux} inference engines.}

\item{eps}{numeric. Epsilon value for \code{meanfield} inference engine.}

\item{inf.engine}{external pointer to the inference engine C++ model.}
}

\value{List of n dataframes. Each dataframe contains the expected time spent in a state (diagonal elements) and the expected number of transitions from one state to another state (off-diagonal elements). Each state is specified in the row (from) and column (to) headers.
\code{NULL} in the case of errors.}

\seealso{
\code{\link{QueryCtbnTime}}, 
\code{\link{QueryCtbnFilter}}, 
\code{\link{QueryCtbnSmooth}}.
}

\examples{

# load ctbn and trajectory
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
trj.file  <- system.file("DrugNetwork", "Trajectory.csv",    package="ctbn")
trj       <- read.table(trj.file, sep=",", header=TRUE, check.names=FALSE)
xpCtbn    <- LoadRCtbn(ctbn.file)

# sample.part is a partial trajectory (Eating and Drowsy are not observed at some time)
# v1 vector of variable  Eating
# v2 vector of variables Eating and Drowsy
var1 <- "Eating"
var2 <- "Drowsy"
sample.part <- trj
sample.part[5,var1]=-1
sample.part[6,var2]=-1
v1 <- c(var1)
v2 <- c(var1,var2)

print(QueryCtbnStats(xpCtbn, sample.part, v1))
print(QueryCtbnStats(xpCtbn, sample.part, v2))

# delete ctbn
xpCtbn  <- DeleteCtbn(xpCtbn)
garbage <- gc()
}

\keyword{ query: expected time and transitions given variables }
