\name{ReadProbStruct}
\alias{ReadProbStruct}

\title{
ReadProbStruct
}

\description{
Read the definition of both static and dynamic parts of the CTBN object from a textual file.
}

\usage{
ReadProbStruct (pathfile, s.tag=NULL, e.tag=NULL)
}

\arguments{

\item{pathfile}{character. File to be read.}

\item{s.tag}{character. Initial tag, \code{NULL} from the start of the file.}

\item{e.tag}{character. End tag, \code{NULL} to the end of the file.}
}

\value{
List. List (I) of lists (II) of dataframes (III), in which the I level contains the nodes Xn, the second level contains the parents of Xn (Xn|U), and the III level contains the values of Xn given a particular instantiation of its parents (Xn|u) specified as a dataframe. This dataframe can be 1 x m (bn.cpts) or m x m (dyn.cims), where m is number of values that Xn can assume (specified in the column header that must be from 0 to value-1). The names contained in the I level list must be Xn and the names of the II level list must be in the form Xn$U=u.
}

\note{

The file format should be defined as: a row that identifies the variable Xn given a particular instantiation of its parents (Xn|u) and the definition of the respective probabilities in terms of a vector (\code{Vec}) or a matrix (\code{Mat}). See the following two examples.

An excerpt of the definition file of the static component:

\code{
Eating$Hungry=0 \cr
Vec,0,1 \cr
"0",0.1,0.9 \cr 
Concentration$Full stomach=0,Uptake=0 \cr
Vec,0,1,2 \cr
"0",0.7,0.2,0.1 \cr
}

An excerpt of the definition file of the dynamic component:

\code{
Eating$Hungry=0 \cr
Mat,0,1 \cr
"0",-0.01,0.01 \cr
"1",10.0,-10.0 \cr
Concentration$Full stomach=0,Uptake=0 \cr
Mat,0,1,2 \cr
"0",-0.02,0.01,0.01 \cr
"1",0.25,-0.26,0.01 \cr
"2",0.01,0.5,-0.51 \cr
}

}

\seealso{
 \code{\link{WriteProbStruct}}
}

\examples{

# cpts and cims files
bn.cpts.file  <- system.file("DrugNetwork", "DrugNetwork_BN_CPTs.txt",  package="ctbn")
dyn.cims.file <- system.file("DrugNetwork", "DrugNetwork_Dyn_CIMs.txt", package="ctbn")

bn.cpts  <- ReadProbStruct(bn.cpts.file)

dyn.cims <- ReadProbStruct(dyn.cims.file)
}

\keyword{ read probability structure }
