\name{SampleFullTrjs}
\alias{SampleFullTrjs}

\title{
SampleFullTrjs
}

\description{
Sample fully observed trajectories from a given CTBN object.
}

\usage{
SampleFullTrjs (xpCtbn, t.begin=0.0, t.end=10.0, num=10)
}

\arguments{

\item{xpCtbn}{external pointer to the CTBN C++ model.}

\item{t.begin}{numeric. Begin time of the trajectory.}

\item{t.end}{numeric. End time of the trajectory.}

\item{num}{integer. Number of trajectories.}
}

\value{List. List of length \code{num} of dataframes k x n+1. Each dataframe represents a trajectory in which the columns names are the time and the n variables of the CTBN model and the k rows (that can be different from each trajectory) contain the the temporal evolution of the variables. 
Recall that in the CTBN model, only one single variable can change at any single instant, so each row of the dataframe contains at most one state transition of a variable. 
The last row contains all \code{-1} (unknown state) because the variables are observed in the [t1;t2),[t2;t3), ..., [tk-1,tk) time intervals. 
\code{NULL} in the case of errors.}


\seealso{
 \code{\link{SamplePartialTrjs}}
}

\examples{

# load ctbn 
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
xpCtbn    <- LoadRCtbn(ctbn.file)

samplesFull <- SampleFullTrjs(xpCtbn, num=100)

sampleFull  <- samplesFull[[1]]

plot(sampleFull[1:nrow(sampleFull)-1,c(1,4)],type="s",main="Full Trajectory")

# delete ctbn
xpCtbn  <- DeleteCtbn(xpCtbn)
garbage <- gc()
}

\keyword{ sample full trajectories }
