\name{SamplePartialTrjs}
\alias{SamplePartialTrjs}

\title{
SamplePartialTrjs
}

\description{
Sample partially observed trajectories from a given CTBN object.
}

\usage{
SamplePartialTrjs (xpCtbn, t.begin=0.0, t.end=10.0, num=10, 
                     rem.frac=0.1, rem.ite=1)
}

\arguments{

\item{xpCtbn}{external pointer to the CTBN C++ model.}

\item{t.begin}{numeric. Begin time of the trajectory.}

\item{t.end}{numeric. End time of the trajectory.}

\item{num}{integer. Number of trajectories.}

\item{rem.frac}{numeric. Fraction of information removed in each iteration.}

\item{rem.ite}{integer. Number of iterations.}

}

\value{List. List of length \code{num} of dataframes k x n+1. Each dataframe represents a trajectory in which the columns names are the time and the n variables of the CTBN model and the k rows (that can be different from each trajectory) contain the the temporal evolution of the variables. 
Recall that in the CTBN model, only one single variable can change at any single instant, so each row of the dataframe contains at most one state transition of a variable. 
Some information is randomly removed (\code{-1} values) from each trajectory according to the given parameters. The last row contains all \code{-1} (unknown state) because the variables are observed in the [t1;t2),[t2;t3), ..., [tk-1,tk) time intervals. 
\code{NULL} in the case of errors.
}

\seealso{
 \code{\link{SampleFullTrjs}}
}

\examples{

# load ctbn 
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
xpCtbn    <- LoadRCtbn(ctbn.file)

samplesPart <- SamplePartialTrjs(xpCtbn, num=100, rem.frac=0.01)

samplePart  <- samplesPart[[1]]

plot(samplePart[1:nrow(samplePart)-1,c(1,4)],type="s",main="Partial Trajectory")

# delete ctbn
xpCtbn  <- DeleteCtbn(xpCtbn)
garbage <- gc()
}

\keyword{ sample partial trajectories }
